@@ -48,7 +48,9 @@
             var cert = certs[cidx],
                 values = {},
                 value,
-                isError = false;
+                isError = false,
+                isFilterErroneousCerts = KS.XCrypt.isFilterErroneousCerts,
+                isAddToCertsList = true;
 
             // CryptoModule and Cades returns cert as object
             for (var field in cert) {
@@ -100,13 +102,19 @@
                     values[field] = value;
                 }
             }
+            
+            if (isFilterErroneousCerts) {
+                isAddToCertsList = !isError;
+            }
+            
+            if (isAddToCertsList){
+                KS.XCrypt.certsList.push(values);
 
-            KS.XCrypt.certsList.push(values);
-
-            if (!KS.isEmpty(KS.XCrypt.signSettings.keyId) && !certIsRequired(values)) {
-            } else {
-                certGrid.addRecord(values);
-                isEmpty = false;
+                if (!KS.isEmpty(KS.XCrypt.signSettings.keyId) && !certIsRequired(values)) {
+                } else {
+                    certGrid.addRecord(values);
+                    isEmpty = false;
+                }
             }
         }
 
