@@ -4,7 +4,7 @@
     $(warnHtml).appendTo("body");
 }
 
-function getLangsCombo (data, value, handler, view) {
+window.getLangsCombo = function(data, value, handler, view) {
     return {
         xtype: 'combobox',
         parentView: view,
