@@ -23,6 +23,15 @@ BaseSvodView = KS.extend(KS.Ext.ClientView, {
             KS.openUrl.apply(this, arguments);
         },
 
+        downloadFile: function (url) {
+            if (Ext.isEmpty(url)) {
+                console.error('Empty download url');
+                return;
+            }
+
+            KS.downloadFile(url);
+        },
+
         showHtmlProtocolInContainer: function(htmlProtocol) {
             if (htmlProtocol) {
                 try {
