@@ -432,10 +432,9 @@ var vc = NewsView2.prototype;
 
         uploadCallback: function(fileKeys) {
             var view = this;
-            var value = lookupReference(view.fp, 'upload').value;
             view.serverCall({
                 method: 'SaveImage',
-                params: [fileKeys, value],
+                params: [fileKeys],
                 waitMessage: 'Анализ ...',
                 success: view.setData
             });
