@@ -514,7 +514,7 @@ var sc = ReportStructView.superclass;
                 params: [links],
                 success: function (ulrList) {
                     Ext.each(ulrList, function (url) {
-                        KS.openUrl(url);
+                        KS.downloadFile(url);
                     });
                 }
             });
