@@ -168,7 +168,7 @@ BaseReportTaskListView = KS.extend(BaseDictionaryView, {
     downloadZipBatchPrint: function () {
         var view = this.parentView;
         if (!Ext.isEmpty(view.batchArchivePath))
-            view.openUrl(view.batchArchivePath);
+            view.downloadFile(view.batchArchivePath);
     },
 
     setDisabledDownloadBatchBtn: function (disabled) {
@@ -202,6 +202,10 @@ var vc = ReportTaskListView.prototype;
             Svod.ColumnSortingManager.addColumnSorter(this.mainGrid);
 
             this.containerPanel.on('activate', this.viewActivated, this);
+
+            if (this.recycleGrid) {
+                this.recycleGrid.getExcelAdditionals = this.getExcelAdditionals;
+            }
         },
         
         viewActivated: function(){
@@ -352,6 +356,13 @@ var vc = ReportTaskListView.prototype;
                 rnv.containerPanel.ownerCt.setActiveTab(rnv.containerPanel)
 
             ReportTaskListView.superclass.onBeforeClose.call(this);
+        },
+
+        exportToExcel: function(){
+            this.gridPropertyName = this.parentView.isTrashCan()
+                ? 'recycleGrid' 
+                : 'mainGrid';
+            ReportTaskListView.superclass.exportToExcel.call(this);
         }
     });
 }(vc));
