@@ -619,6 +619,7 @@
             if (KS.isEmpty(node)) {
                 this.filePreview.update('');
             } else {
+                node = node[0] || node;
                 var od = this.treeNode.objData;
                 this.filePreview.update('<a href="' + (od['FILE_URL_' + node.id]) + '" target="_blank">Скачать</a>');
             }
@@ -711,7 +712,7 @@
 (function (viewClass) {
     KS.apply(viewClass, {
         downloadPdf: function() {
-            KS.openUrl(this.parentView.treeNode.objData.PDF_URL);
+            KS.downloadFile(this.parentView.treeNode.objData.PDF_URL);
         },
 
         prevPage: function() {
