@@ -27,7 +27,7 @@
         processResult: function(result) {
             this.data.resultUrl = result;
             if (!this.data.showResultView) {
-                this.openUrl(result);
+                this.downloadFile(result);
                 this.close();
             }
             else {
@@ -517,7 +517,7 @@
         downloadSpreadsheet: function () {
             var view = this.parentView || this;
             //view.spreadsheetView.downloadExcelFile();
-            view.openUrl(view.data.resultUrl);
+            view.downloadFile(view.data.resultUrl);
         },
 
         modifyColumnInSpreadsheet: function (colIndex, rowIndex, columnText, dataFormula, constantsObj) {
