@@ -386,9 +386,9 @@ UniDictItemView = KS.extend(BaseSvodView, {
             var grid = (isHistory) ? this.rowsHistoryGrid : this.rowsGrid;
             rowDict['DATE'] = eval(rowDict['DATE'].replaceAll('/', ''));
             rowDict['END_DATE'] = eval(rowDict['END_DATE'].replaceAll('/', ''));
-            grid.addRecord(rowDict);
+            grid.getStore().insert(0, rowDict);
             this.touch();
-            var rowIdx = grid.store.getCount() - 1,
+            var rowIdx = 0,
                 startEditColIdx = (isHistory)
                     ? this.defaultSelectRowsHistoryColumnIndex
                     : this.defaultSelectRowsColumnIndex;
