@@ -5,13 +5,13 @@ var sc = UserView.superclass;
 (function(viewClass) {
     KS.apply(viewClass, {
         onTemplateRendered: function() {
-            if (this.data.identifier && this.data.identifier.EditMode === 1) return;
+            this.cachedValues = [];
+            if (this.data.isOnlyDetails) return;
             // При чтении заявки на изменение пароль может быть уже заполнен
             var hasNewPassword = this.changePassword && this.changePassword.checkboxCmp && this.changePassword.checkboxCmp.getValue();
             if (this.data.isNewOutcome || hasNewPassword)
                 this.touch();
             this.setNewTreeCheckStyles();
-            this.cachedValues = [];
         },
 
         onValuesSelected: function (arg) {
@@ -226,9 +226,12 @@ var sc = UserView.superclass;
         },
 
         collectValues: function() {
-            var values = {
-                "NOTE" : this.noteField.getValue().toString()                
-            };
+            var values = {};
+
+            if (!this.data.isOnlyDetails) {
+                values["NOTE"] = this.noteField.getValue().toString();                
+            }
+
             if (this.data.userType !== 2 &&
                 !this.data.isTemplate) 
             {
@@ -236,9 +239,15 @@ var sc = UserView.superclass;
                 values["POST"] = this.post.getValue().toString();
                 values["PHONE"] = this.phone.getValue().toString();
                 values["EMAIL"] = this.email.getValue().toString();
-                values["IS_ADMIN_SP"] = this.updateAdmin.getValue();
                 values["KEYID"] = this.certEditor.getValue();
                 values["CERTISSUER"] = this.issuerEditor.getValue();
+                values["KEYID_NOTBEFORE"] = this.generalNotBefore.getValue();
+                values["KEYID_NOTAFTER"] = this.generalNotAfter.getValue();
+                values["ALLOW_CERT_API"] = this.allowCertApi.getValue() ? 1 : 0;
+
+                if (!this.data.isOnlyDetails) {
+                    values["IS_ADMIN_SP"] = this.updateAdmin.getValue();
+                }
             }
             if (this.data.loginEditable) 
                 values["LOGIN"] = this.userName.getValue().toString();
@@ -247,8 +256,11 @@ var sc = UserView.superclass;
         },
 
         setUserData: function(){
-            if (!Ext.isEmpty(this.data.userDataDict)){ 
-                this.noteField.setValue(this.data.userDataDict["NOTE"]);
+            if (!Ext.isEmpty(this.data.userDataDict)){
+                if (!this.data.isOnlyDetails) {
+                    this.noteField.setValue(this.data.userDataDict["NOTE"]);
+                    this.userRoles.setValue(this.data.userType);
+                }
 
                 if (this.data.userType !== 2 &&
                     !this.data.isTemplate)
@@ -257,12 +269,17 @@ var sc = UserView.superclass;
                     this.post.setValue(this.data.userDataDict["POST"]);
                     this.phone.setValue(this.data.userDataDict["PHONE"]);
                     this.email.setValue(this.data.userDataDict["EMAIL"]);
+                    this.certEditor.setValue(this.data.userDataDict["KEYID"]);
+                    this.issuerEditor.setValue(this.data.userDataDict["CERTISSUER"]);
+                    this.generalNotBefore.setValue(this.data.userDataDict["KEYID_NOTBEFORE"]);
+                    this.generalNotAfter.setValue(this.data.userDataDict["KEYID_NOTAFTER"]);
+                    this.allowCertApi.setValue(this.data.userDataDict["ALLOW_CERT_API"]);
 
-                    this.updateAdmin.setRawValue(this.data.userDataDict["IS_ADMIN_SP"]);
+                    if (!this.data.isOnlyDetails) {
+                        this.updateAdmin.setRawValue(this.data.userDataDict["IS_ADMIN_SP"]);
+                    }
                 }
-                
-                this.userRoles.setValue(this.data.userType);
-              
+
                 this.discardChanges();
             }
         },
@@ -282,15 +299,6 @@ var sc = UserView.superclass;
                     view.touch();
                 }
             });
-        },
-
-        fieldChange: function (field, newValue) {
-            this.serverCall({
-                method: 'SetValue',
-                params: [field.ownerCt.ctrlId, newValue],
-                disableFog: true,
-                success: this.touch
-            });
         }
     });
 }(UserView.prototype));
@@ -349,32 +357,8 @@ var sc = UserView.superclass;
                 saveBtn.setDisabled(saved);
         },
         
-        // Для "Реквизиты пользователя"
-        baseSaveChanges: function (close) {
-            var view = this.parentView || this;
-            view.serverCall({
-                method: 'SaveChanges',
-                waitMessage: 'Сохранение ...',
-                success: function (hasSaveErrors) {
-                    if (hasSaveErrors === true) {
-                        KS.alert('Документ не сохранен!');
-                        return;
-                    }
-                    this.discardChanges();
-                    if (close === true) 
-                        this.close();
-                    else 
-                        this.reload();
-                }
-            });
-        },
-        
         saveChanges: function(callback) {
             var view = this.parentView || this;
-            if (view.data.identifier && view.data.identifier.EditMode === 1) {
-                view.baseSaveChanges();
-                return;
-            }
             var values = view.collectValues();
             var checkPasswordSuccess = true;
             if (view.data.passwordChanged) 
@@ -422,9 +406,6 @@ var sc = UserView.superclass;
         },
         
         doReload: function () {
-            if (this.data.identifier && this.data.identifier.EditMode === 1) 
-                return;
-            
             this.cachedValues = [];
             this.serverCall({
                 method: 'Reload',
@@ -432,19 +413,21 @@ var sc = UserView.superclass;
                 success: this.reloadCallback
             });
         },
-        
-        resetView: function () {
-            var activeTab = this.rootTabPanel.getActiveTab();
-            this.eachTabPanel(function(tabPanel) {
-                tabPanel.needRefresh = true;
-            });
-            this.activateTabHandler(null, activeTab);
 
-            if (this.changePassword && this.changePassword.checkboxCmp) {
-                //Триггерит collapseChangePassword
-                this.changePassword.checkboxCmp.setValue(false);
+        resetView: function () {
+            if (!this.data.isOnlyDetails) {
+                var activeTab = this.rootTabPanel.getActiveTab();
+                this.eachTabPanel(function (tabPanel) {
+                    tabPanel.needRefresh = true;
+                });
+                this.activateTabHandler(null, activeTab);
+
+                if (this.changePassword && this.changePassword.checkboxCmp) {
+                    //Триггерит collapseChangePassword
+                    this.changePassword.checkboxCmp.setValue(false);
+                }
             }
-            
+
             this.setUserData();
         },
         
@@ -1779,13 +1762,18 @@ var sc = UserView.superclass;
                 // var certSerial = '#' + certData.serial.toUpperCase();
                 this.certEditor.setValue(certData.serial.toUpperCase());
                 this.issuerEditor.setValue(certData.issuer);
+                this.generalNotBefore.setValue(certData.notbefore);
+                this.generalNotAfter.setValue(certData.notafter);
                 this.touch();
             }
         },
 
         authCertEditorChange: function(comp, newValue){
-            if (Ext.isEmpty(newValue))
+            if (Ext.isEmpty(newValue)) {
                 this.issuerEditor.setValue('');
+                this.generalNotBefore.setValue('');
+                this.generalNotAfter.setValue('');
+            }
             this.touch();
         },
 
