@@ -382,7 +382,7 @@ KS.apply(KS,
                 waitMessage: 'Сохранение протокола ...',
                 success: function (fileKey) {
                     if (!Ext.isEmpty(fileKey)) {
-                        KS.openUrl(fileKey);
+                        KS.downloadFile(fileKey);
                     }
                 }
             });            
@@ -1272,7 +1272,7 @@ KS.apply(KS,
         openLogUrl : function(fileName, isArchive){
             var url = String(window.location.href).replace(/Workspace.*/,
                 (isArchive ? 'temp/ArchiveLogs/' : 'temp/logs/') + fileName);
-            KS.openUrl(url);
+            KS.downloadFile(url);
         },
 
         downloadFile : function() {
